=======
Startup
=======

Sub-commands to support the startup components

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.startup.CARTESIAN
   rompy_swan.subcomponents.startup.SPHERICAL
